package urpmi;

# Dummy package for CPAN testers

our $VERSION = '8.120';

1;
